@@ -106,7 +106,8 @@ class LinuxDeviceSerializer(serializers.ModelSerializer):
 
     @swagger_serializer_method(serializer_or_field=serializers.JSONField)
     def get_object(self, instance):
-        serializer = get_serializer_for_model(instance.content_type.model_class(), prefix=NESTED_SERIALIZER_PREFIX)
+        # serializer = get_serializer_for_model(instance.content_type.model_class(), prefix=NESTED_SERIALIZER_PREFIX)
+        serializer = get_serializer_for_model(instance.content_type.model_class())
         context = {'request': self.context['request']}
         return serializer(instance.object, context=context).data
 
@@ -143,17 +144,19 @@ class VolumeGroupSerializer(serializers.ModelSerializer):
 
 
 class LogicalVolumeSerializer(serializers.ModelSerializer):
-    device = NestedLinuxDeviceSerializer(required=False, allow_null=True)
+    url = serializers.HyperlinkedIdentityField(
+        view_name="plugins-api:netbox_storage-api:logicalvolume-detail"
+    )
     vg = NestedVolumeGroupSerializer(required=False, allow_null=True)
 
     class Meta:
         model = LogicalVolume
         fields = (
             "id",
+            'url',
             "vg",
             "lv_name",
             "size",
-            "device",
             "description",
             "created",
             "last_updated",
