@@ -56,6 +56,7 @@ class LVMTemplateForm(NetBoxModelForm):
         required=False,
         label="Filesystem Options",
         help_text="The mounted point of the volume e.g. /var/lib/docker",
+        default='defaults',
     )
     checkbox_partition = BooleanField(
         label="Create extra partition",
@@ -121,27 +122,32 @@ class LVMTemplateForm(NetBoxModelForm):
         volume_group = VolumeGroup.objects.create(vg_name=self.cleaned_data['vg_name'])
         #print(f"Volume Group ID: {volume_group.id}")
 
-        #pv = PhysicalVolume.objects.create(device=pv_linux_device, vg=volume_group)
+        pv = PhysicalVolume.objects.create(linux_device=pv_linux_device, vg=volume_group)
         #pv.save()
         #print(f"Physical Volume ID: {pv.id}")
 
         # Add linux_device for lvm
-        pv_type_pk = ContentType.objects.get(app_label='netbox_storage', model='volumegroup').pk
-        linux_device_mapper = LinuxDevice.objects.create(device='/dev/mapper/vg_system-lv_home',
-                                                         type='LVM',
-                                                         size=pv_linux_device.size,
-                                                         object_id=volume_group.pk,
-                                                         content_type_id=pv_type_pk)
+        lv_type_pk = ContentType.objects.get(app_label='netbox_storage', model='logicalvolume').pk
+
         #print(f"Linux Device ID: {linux_device_mapper.id}")
 
         self.instance.vg = volume_group
-        self.instance.device = linux_device_mapper
         #lv = LogicalVolume.objects.create(vg=volume_group, lv_name=self.cleaned_data['lv_name'],
         #                                  size=self.cleaned_data['size'], device=linux_device_mapper)
         #lv.save()
         #print(f"{lv}")
         lv = super().save(*args, **kwargs)
 
+        linux_device_mapper = LinuxDevice.objects.create(device='/dev/mapper/vg_system-lv_home',
+                                                         type='LVM',
+                                                         size=pv_linux_device.size,
+                                                         object_id=lv.pk,
+                                                         content_type_id=lv_type_pk)
+
+        MountedVolume.objects.create(linux_device=linux_device_mapper,
+                                     mount_point=self.cleaned_data['mountpoint'],
+                                     fs_type=self.cleaned_data['fs_type'],
+                                     options=self.cleaned_data['fs_options'])
         return lv
 
 
