@@ -1,3 +1,5 @@
+import django_tables2 as tables
+
 from netbox.tables import (
     NetBoxTable,
     ToggleColumn,
@@ -10,6 +12,12 @@ class LogicalVolumeTable(NetBoxTable):
     """Table for displaying LogicalVolume objects."""
 
     pk = ToggleColumn()
+    lv_name = tables.Column(
+        linkify=True
+    )
+    size = tables.Column(
+        linkify=True
+    )
 
     class Meta(NetBoxTable.Meta):
         model = LogicalVolume
@@ -18,13 +26,11 @@ class LogicalVolumeTable(NetBoxTable):
             "vg",
             "lv_name",
             "size",
-            "device",
             "description",
         )
         default_columns = (
             "vg",
             "lv_name",
             "size",
-            "device",
             "description",
         )
