@@ -2,7 +2,7 @@ from django.contrib.contenttypes.models import ContentType
 
 from extras.plugins import PluginTemplateExtension
 from netbox_storage.models import LogicalVolume, StorageConfigurationDrive, \
-    TemplateConfigurationDrive, Drive, Partition, LinuxDevice
+    TemplateConfigurationDrive, Drive, Partition, LinuxDevice, MountedVolume
 
 
 class RelatedDrives(PluginTemplateExtension):
@@ -44,56 +44,47 @@ class TemplateVolumeConfig(PluginTemplateExtension):
     model = "dcim.platform"
 
     def right_page(self):
-        print(LinuxDevice.objects.all())
         obj = self.context.get("object")
 
-        drives = TemplateConfigurationDrive.objects.values('drive').filter(platform=obj)
-        drives_id = []
-        lonely_drives = []
-        drives_with_partition = []
-        partitions = []
+        drives_id = TemplateConfigurationDrive.objects.values('drive').filter(platform=obj)
         partition_dict = {
         }
-        for drive_id in drives:
-            print(f"Right Page: {drive_id['drive']}")
-            drives_id.append(drive_id['drive'])
+        for drive_id in drives_id:
+            print(f"Drive ID: {drive_id['drive']}")
             drive = Drive.objects.get(pk=drive_id['drive'])
 
             drive_type_id = ContentType.objects.get(app_label='netbox_storage', model='drive').pk
             linux_device_type_id = ContentType.objects.get(app_label='netbox_storage', model='linuxdevice').pk
-            print(f"{drive_type_id}, {drive_id['drive']}")
             # Get Linux Device of Drive e.g. /dev/sda
-            linux_device_drive = LinuxDevice.objects.get(content_type_id=drive_type_id, object_id=drive_id['drive'], type='disk')
-            print(f"Count: {linux_device_drive}")
-            # Wenn es keine Partition hat zu lonely_drives hinzufügen
-            if LinuxDevice.objects.filter(content_type_id=linux_device_type_id, object_id=linux_device_drive.pk,
+            linux_device_drive = LinuxDevice.objects.get(content_type_id=drive_type_id,
+                                                         object_id=drive_id['drive'],
+                                                         type='Disk')
+
+            if LinuxDevice.objects.filter(content_type_id=linux_device_type_id,
+                                          object_id=linux_device_drive.pk,
                                           type='Partition').count() == 0:
-                print(f"Right Page Lonely Drive: {drive}")
-                lonely_drives.append(drive)
                 partition_dict[drive] = None
             else:
-                drives_with_partition.append(drive)
-                partitions.append(list(LinuxDevice.objects.filter(content_type_id=linux_device_type_id,
-                                                                  object_id=linux_device_drive.pk, type='Partition')))
                 partition_dict[drive] = list(LinuxDevice.objects.filter(content_type_id=linux_device_type_id,
-                                                                                   object_id=linux_device_drive.pk,
-                                                                                   type='Partition'))
-
-        amount_partitions = len(partitions)
-        print(f"R Lonely Drives: {lonely_drives}")
-        print(f"Amount Partitions: {drives_id}")
+                                                                        object_id=linux_device_drive.pk,
+                                                                        type='Partition'))
 
         return self.render(
             "netbox_storage/inc/template_drive_box.html",
             extra_context={
-                "lonely_drives": lonely_drives,
-                "drives": drives_with_partition,
-                "partitions": partitions,
-                "amount_partitions": amount_partitions,
                 "partition_dict": partition_dict
             }
         )
 
+    def left_page(self):
+        mounted_volumes = MountedVolume.objects.all()
+        return self.render(
+            "netbox_storage/inc/template_volume_box.html",
+            extra_context={
+                "mounted_volumes": mounted_volumes
+            }
+        )
+
     def full_width_page(self):
         obj = self.context.get("object")
 
